[![Build Status](https://travis-ci.org/subramaniank/drf-eventlog.svg?branch=master)](https://travis-ci.org/subramaniank/drf-eventlog)

[![Coverage Status](https://coveralls.io/repos/subramaniank/drf-eventlog/badge.svg?branch=master&service=github)](https://coveralls.io/github/subramaniank/drf-eventlog?branch=master)

# drf-eventlog

EventLog app with DRF APIs to quickly track events and query them
